@@ -187,7 +187,13 @@ class Watch(SubCommand):
             obj=obj,
             default_owner=self.sync.default_owner
         )
-        self.sync.fs_write(path=path, data=data)
+
+        pathinfo = self.sync.fs_write(path=path, data=data)
+        path_layer = pathinfo['layers'][pathinfo['layeridx']]['ident']
+        current_layer = getattr(obj, 'zodbsync_layer', None)
+        if current_layer != path_layer:
+            with self.sync.tm:
+                obj.zodbsync_layer = path_layer
 
     def _update_objects(self):
         '''
@@ -273,7 +279,6 @@ class Watch(SubCommand):
         """
         Signal handler
         """
-        self.logger.info('Caught signal, exiting...')
         self.unregister_signals()
         self.exit.set()
 
@@ -432,3 +437,5 @@ class Watch(SubCommand):
             self.step()
             # a wait that is interrupted immediately if exit.set() is called
             self.exit.wait(interval)
+
+        self.logger.info('Exited due to signal')
